# SQL-Cable

## What is SQL-Cable?
SQL-Cable is package designed to make it easier to work with a flask app and sqlite3 database.

## How do I use SQL-Cable?
You can read the [docs](https://sql-cable.readthedocs.io/en/latest/).
